import { Vector3 } from "three";
import { EBoardKeyList } from "../Common/BoardKeyList";
import { GangDrillType } from "../DatabaseServices/3DSolid/CylinderHole";
import { Board, I2DModeingItem, IKnifeInfo } from "../DatabaseServices/Entity/Board";
import { ExtrudeContourCurve } from "../DatabaseServices/Entity/Extrude";
import { Polyline } from "../DatabaseServices/Entity/Polyline";
import { HardwareCompositeEntity } from "../DatabaseServices/Hardware/HardwareCompositeEntity";
import { HardwareTopline } from "../DatabaseServices/Hardware/HardwareTopline";
import { IHardwareOption } from "../UI/Components/RightPanel/RightPanelInterface";
import { BoardOpenDir, FaceDirection, ISealingData } from "../UI/Store/BoardInterface";
import { Entity } from './../DatabaseServices/Entity/Entity';
import { IContourData } from "./Convert2PtsBul";
export interface I3DContourData {
    pts: Vector3[];
    buls: number[];
}
export type IHardwareType = HardwareTopline | HardwareCompositeEntity;
export interface IModelingData {
    feeding: IContourData[];
    thickness: number;
    dir: FaceDirection | number;
    knifeRadius: number;
    origin: IOriginModelingData;
}
export interface IDrillingOption {
    position: Vector3;
    radius: number;
    type: GangDrillType;
    depth: number;
    face: FaceDirection;
    endPt?: Vector3;
    angle?: number;
}
export interface IBoardHoleInfo {
    frontBackHoles: IDrillingOption[];
    sideHoles: IDrillingOption[];
}
interface IBoardProdInfo {
    id: number;
    name: string;
    [EBoardKeyList.RoomName]: string;
    [EBoardKeyList.CabinetName]: string;
    [EBoardKeyList.Mat]: string;
    [EBoardKeyList.BrMat]: string;
    [EBoardKeyList.Color]: string;
    [EBoardKeyList.Lines]: number;
    [EBoardKeyList.DrillType]: string;
    spliteHeight: string;
    spliteThickness: string;
    spliteWidth: string;
    isRect: boolean;
    remarks: [string, string][];
    kaiLiaoWidth: number;
    kaiLiaoHeight: number;
    openDir: BoardOpenDir;
}
export interface I2DModeling {
    path: IContourData;
    dir: FaceDirection;
    items: I2DModeingItem[];
}
export interface I3DModeling {
    path: I3DContourData;
    dir: FaceDirection;
    knife: IKnifeInfo;
}
/**拆单数据 */
export interface ISpliteOrderData {
    info: IBoardProdInfo;
    outline: IContourData;
    sealing: ISealingData[];
    modeling: IModelingData[];
    holes: IBoardHoleInfo;
    sideModeling: IModelingData[];
    offsetTanslation: Vector3;
    originOutlin: IContourData;
    metalsData?: {
        metals: number;
        comp: number;
    };
    boardContour: IContourData;
    modeling2D: I2DModeling[];
    modeling3D: I3DModeling[];
}
export interface IBoardMetalsData {
    metals: ISpliteHardwareData[];
    comp: ISpliteHardwareData[];
}
export interface ISpliteHardwareData {
    metalsOption: IHardwareOption;
    dataList: [string, string][];
    children: ISpliteHardwareData[];
    length?: number;
    size: Vector3;
}
export interface IOriginModelingData {
    outline: IContourData;
    holes: IContourData[];
    thickness?: number;
    dir?: FaceDirection | number;
    knifeRadius?: number;
    addLen?: number;
    addWidth?: number;
    addDepth?: number;
}
interface IChaiDanFeedingData extends IOriginModelingData {
    boardContour: IContourData;
    brThickness: number;
}
export declare namespace Production {
    /**获取板件拆单数据 */
    function GetBoardSplitOrderData(br: Board): ISpliteOrderData | undefined;
    function GetBoardInfo(br: Board, size: Vector3): IBoardProdInfo;
    function GetMetalTotalEntitys(md: HardwareCompositeEntity, isHole?: boolean, filter?: (e: Entity) => boolean): Entity[];
    function GetOriginBoardModelingData(br: Board): {
        modeling: IOriginModelingData[];
        sideModeling: IOriginModelingData[];
    };
    function GetBoardModelingData(br: Board, offsetTanslation: Vector3): {
        modeling: IModelingData[];
        sideModeling: IModelingData[];
    };
    /**获取板件的轮廓
    *有拆单尺寸返回矩形
    *用于拆单的轮廓统一逆时针 */
    function GetSpliteOutline(br: Board, isSplite: boolean): ExtrudeContourCurve | undefined;
    function GetSpiteSize(br: Board): {
        spliteHeight: number;
        spliteWidth: number;
        spliteThickness: number;
    };
    function GetSpliteOutlineBySpliteSize(br: Board): Polyline | null;
    /**孔信息,侧孔的z 均为 从上到下距离 */
    function GetBoardHolesData(br: Board, offsetTanslation: Vector3, sealedContour: ExtrudeContourCurve): IBoardHoleInfo;
    function GetHardwareCompositeData(en: HardwareCompositeEntity): ISpliteHardwareData;
    function GetHardwareToplineData(en: HardwareTopline): ISpliteHardwareData[];
    /**获取排钻数量 */
    function GetTotalDrillCount(brs: (Board | IHardwareType)[]): {
        drillCount: import("../Add-on/LookOverBoardInfos/LookOverBoardInfosTool").ICountType<IHardwareType>[];
        hardwareCount: import("../Add-on/LookOverBoardInfos/LookOverBoardInfosTool").ICountType<IHardwareType>[];
        sealCount: import("../Add-on/LookOverBoardInfos/LookOverBoardInfosTool").ICountType<IHardwareType>[];
        areaCount: import("../Add-on/LookOverBoardInfos/LookOverBoardInfosTool").ICountType<Board>[];
    };
    function GetCabSize(brList: Board[]): Map<Board, Vector3>;
    function Data2Polyline(data: IContourData, isClose?: boolean): Polyline;
    function Get2DModeing(br: Board, offset: Vector3): I2DModeling[];
    function Get3DModeing(br: Board, offset: Vector3): I3DModeling[];
    function GetChaiDanFeedingPath(data: IChaiDanFeedingData): IContourData[];
}
export {};
//# sourceMappingURL=Product.d.ts.map